#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# dernières révisions       : 15/05/2007
#
# zenbuild inspired by Peter van Eerte's powermanga ZenBuild
#
#package			: powermanga
#homepage			: http://linux.tlk.fr/games/Powermanga/
#source location	: http://freshmeat.net/redir/powermanga/8300/url_tgz/powermanga.tgz
#dependency         : sdl

softname='powermanga'
softversion='0.90'
packageversion='64.1'

#
# ZenWalk standard: type CPUet architecture
#
# arch='i486' -> le compileur utilise seulement les instructions 80486
# cpu='i686'  -> optimisation faîte pour PII et >
#
arch='i486'
cpu='i686'

#
# destination du package
#
prefix=/usr

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "gros" PC: 6 compilations à la fois
#
# numjobs='-j6'
#
# "léger" PC: 2 compilations à la fois
#
numjobs='-j2'

# log ;)
(

#
# paramètres pour compiler
#
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname.tgz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://freshmeat.net/redir/powermanga/8300/url_tgz/powermanga.tgz

#
# preparer le répertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/$softname
mkdir -p $dest/usr/share/$softname/scores
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc 
          |-----handy-ruler------------------------------------------------------|
powermanga: Powermanga 0.80
powermanga:
powermanga: Powermanga is an arcade 2D shoot-em-up game with 41 levels
powermanga: and more than 200 sprites. It runs in 320x200 or 640x400 pixels,
powermanga: with Window mode or full screen and support for 8, 15, 16, 24,
powermanga: and 32 bpp.
powermanga:
powermanga:
powermanga:
powermanga:
powermanga:
EOF

#
# Verifie si package est present
#
if [ -f $softname.tgz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
tar zxvf $srcpkg
cd $src

#
# "faire" le package package
#
sed -i -e 's|CFLAGS="-O3 -Wall -std=c99"|CFLAGS="${CFLAGS}"|g' configure.ac
sed -i -e 's|/share/games/powermanga/|/share/powermanga/|g' src/tools.c  #permet de lancer le jeu depuis /usr/bin

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
    
./configure --prefix=/usr --bindir=/usr/bin --mandir=/usr/man 

#
# "faire" le package package
#
sed -i -e 's|gamesdir = $(prefix)/games|gamesdir = $(prefix)/share|g' src/Makefile
sed -i -e 's|gamesdir = $(prefix)/games|gamesdir = $(prefix)/share|g' src/Makefile.am
sed -i -e 's|gamesdir = $(prefix)/games|gamesdir = $(prefix)/share|g' src/Makefile.in

sed -i -e 's|scoredir = /var/games|scoredir = /usr/share/powermanga/scores|g' src/Makefile
sed -i -e 's|scoredir = /var/games|scoredir = /usr/share/powermanga/scores|g' src/Makefile.am
sed -i -e 's|scoredir = /var/games|scoredir = /usr/share/powermanga/scores|g' src/Makefile.in

sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/data|pkgdatadir = $(datadir)/powermanga/data|g' data/Makefile
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/data|pkgdatadir = $(datadir)/powermanga/data|g' data/Makefile.am
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/data|pkgdatadir = $(datadir)/powermanga/data|g' data/Makefile.in

sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/data/curves|pkgdatadir = $(datadir)/powermanga/data/curves|g' data/curves/Makefile
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/data/curves|pkgdatadir = $(datadir)/powermanga/data/curves|g' data/curves/Makefile.am
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/data/curves|pkgdatadir = $(datadir)/powermanga/data/curves|g' data/curves/Makefile.in

sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/data/levels/curves_phase|pkgdatadir = $(datadir)/powermanga/data/levels/curves_phase|g' data/levels/curves_phase/Makefile
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/data/levels/curves_phase|pkgdatadir = $(datadir)/powermanga/data/levels/curves_phase|g' data/levels/curves_phase/Makefile.am
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/data/levels/curves_phase|pkgdatadir = $(datadir)/powermanga/data/levels/curves_phase|g' data/levels/curves_phase/Makefile.in

sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/data/levels/grids_phase|pkgdatadir = $(datadir)/powermanga/data/levels/grids_phase|g' data/levels/grids_phase/Makefile
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/data/levels/grids_phase|pkgdatadir = $(datadir)/powermanga/data/levels/grids_phase|g' data/levels/grids_phase/Makefile.am
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/data/levels/grids_phase|pkgdatadir = $(datadir)/powermanga/data/levels/grids_phase|g' data/levels/grids_phase/Makefile.in

sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics|pkgdatadir = $(datadir)/powermanga/graphics|g' graphics/Makefile
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics|pkgdatadir = $(datadir)/powermanga/graphics|g' graphics/Makefile.am
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics|pkgdatadir = $(datadir)/powermanga/graphics|g' graphics/Makefile.in

sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/bitmap|pkgdatadir = $(datadir)/powermanga/graphics/bitmap|g' graphics/bitmap/Makefile
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/bitmap|pkgdatadir = $(datadir)/powermanga/graphics/bitmap|g' graphics/bitmap/Makefile.am
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/bitmap|pkgdatadir = $(datadir)/powermanga/graphics/bitmap|g' graphics/bitmap/Makefile.in

sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/bitmap/fonts|pkgdatadir = $(datadir)/powermanga/graphics/bitmap/fonts|g' graphics/bitmap/fonts/Makefile
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/bitmap/fonts|pkgdatadir = $(datadir)/powermanga/graphics/bitmap/fonts|g' graphics/bitmap/fonts/Makefile.am
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/bitmap/fonts|pkgdatadir = $(datadir)/powermanga/graphics/bitmap/fonts|g' graphics/bitmap/fonts/Makefile.in

sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/sprites|pkgdatadir = $(datadir)/powermanga/graphics/sprites|g' graphics/sprites/Makefile
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/sprites|pkgdatadir = $(datadir)/powermanga/graphics/sprites|g' graphics/sprites/Makefile.am
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/sprites|pkgdatadir = $(datadir)/powermanga/graphics/sprites|g' graphics/sprites/Makefile.in

sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/sprites/guardians|pkgdatadir = $(datadir)/powermanga/graphics/sprites/guardians|g' graphics/sprites/guardians/Makefile
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/sprites/guardians|pkgdatadir = $(datadir)/powermanga/graphics/sprites/guardians|g' graphics/sprites/guardians/Makefile.am
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/sprites/guardians|pkgdatadir = $(datadir)/powermanga/graphics/sprites/guardians|g' graphics/sprites/guardians/Makefile

sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/sprites/meteors|pkgdatadir = $(datadir)/powermanga/graphics/sprites/meteors|g' graphics/sprites/meteors/Makefile
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/sprites/meteors|pkgdatadir = $(datadir)/powermanga/graphics/sprites/meteors|g' graphics/sprites/meteors/Makefile.am
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/sprites/meteors|pkgdatadir = $(datadir)/powermanga/graphics/sprites/meteors|g' graphics/sprites/meteors/Makefile

sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/sprites/spaceships|pkgdatadir = $(datadir)/powermanga/graphics/sprites/spaceships|g' graphics/sprites/spaceships/Makefile
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/sprites/spaceships|pkgdatadir = $(datadir)/powermanga/graphics/sprites/spaceships|g' graphics/sprites/spaceships/Makefile.am
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/sprites/spaceships|pkgdatadir = $(datadir)/powermanga/graphics/sprites/spaceships|g' graphics/sprites/spaceships/Makefile

sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/sprites/stars|pkgdatadir = $(datadir)/powermanga/graphics/sprites/stars|g' graphics/sprites/stars/Makefile
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/sprites/stars|pkgdatadir = $(datadir)/powermanga/graphics/sprites/stars|g' graphics/sprites/stars/Makefile.am
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/graphics/sprites/stars|pkgdatadir = $(datadir)/powermanga/graphics/sprites/stars|g' graphics/sprites/stars/Makefile

sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/sounds|pkgdatadir = $(datadir)/powermanga/sounds|g' sounds/Makefile
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/sounds|pkgdatadir = $(datadir)/powermanga/sounds|g' sounds/Makefile.am
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/sounds|pkgdatadir = $(datadir)/powermanga/sounds|g' sounds/Makefile.in    

sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/sound/handheld_console|pkgdatadir = $(datadir)/powermanga/sounds/handheld_console|g' sounds/handheld_console/Makefile
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/sound/handheld_console|pkgdatadir = $(datadir)/powermanga/sounds/handheld_console|g' sounds/handheld_console/Makefile.am
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/sound/handheld_console|pkgdatadir = $(datadir)/powermanga/sounds/handheld_console|g' sounds/handheld_console/Makefile.in

sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/texts|pkgdatadir = $(datadir)/powermanga/texts|g' texts/Makefile
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/texts|pkgdatadir = $(datadir)/powermanga/texts|g' texts/Makefile.am
sed -i -e 's|pkgdatadir = $(datadir)/games/powermanga/texts|pkgdatadir = $(datadir)/powermanga/texts|g' texts/Makefile.in    

make $numjobs DESTDIR=$dest

#
# installer le package dans son répertoire de destination
#
    
make install DESTDIR=$dest
   
cp src/powermanga $dest/usr/bin/powermanga
   
rm -rf $dest/usr/games
    
chmod -R -s $dest/$prefix/share/$softname

#
# "faire" icon
#
cp ../powermanga.png $dest/usr/share/icons/hicolor/48x48/apps/

# "faire" .desktop
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Powermanga
Comment=2D Shooting game
Exec=powermanga
Terminal=false
Type=Application
Categories=Game;ActionGame
Icon=powermanga
EOF

#
# ajout des fichiers de docs, infos, ...
#
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING CHANGES README\
      $dest/usr/doc/$softname-$softversion

#
# Stripper les éxécutables
# (Commenter ces lignes si besoin d'infos de débuggage)
#
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# Compresser les pages Man
#
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

#
# Mettre le zenbuild à sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

chmod 666 $dest/$prefix/share/$softname/scores
chmod 666 $dest/$prefix/share/$softname/scores/powermanga*   

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.txz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.txz > $package.md5

#
# produire le fichier .dep
#
cd $buildir
echo -e "coreutils,cxxlibs,expat,fontconfig,freetype,gcc,gdbm,libdrm,libjpeg,libpng,libtiff,libmikmod,mesa\
,ncurses,openssl,perl,sdl,sysfsutils,xorg-server,zlib" > $package.dep

# generate source file
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/games/powermanga/source/build-powermanga.sh > $package.src
echo $source >> $package.src


#
# supprimer source
#
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
